export const header = {
  heading: "GPG Key",
  subheading: "Information about my public GPG key and how to obtain it.",
};

const gpgFingerprint = `
pub   ed25519/E48D7F49A852F112 2023-07-14 [SC]
      Key fingerprint = DBD3 8E38 4B9E 1F4F 19F9  5BAE E48D 7F49 A852 F112
uid                 Foster Hangdaan <foster@hangdaan.email>
`;

export default function() {
  return (
    <>
      <section>
        <h2>Intro</h2>
        <p>
          If you would like to obtain my key but you are not familiar with GPG, then I suggest reading up on GPG before proceeding.
          You can find more information and guides about GPG on the <a href="https://gnupg.org/" target="_blank">GnuPG official website</a>.
        </p>
        <p>
          I do not use keyservers.
          This is the only place where I provide my key.
          A key claiming to be mine somewhere else is definitely a fake.
        </p>
        <p>You can utilize the public key here to verify software and binaries released by me.</p>
        <p>
          You can also use the key to encrypt emails you send to me. In that case, I would also need your public key so I can encrypt the emails I send back to you.
          The excellent <a href="https://emailselfdefense.fsf.org/" target="_blank">Email Self-Defense Guide by the Free Software Foundation</a> describes how this process works.
        </p>
      </section>
      <section>
        <h2>Obtaining my key</h2>
        <p>
          First, <a href="https://static.fosterhangdaan.com/foster-pubkey.asc" target="_blank" download>download my public key</a>.
        </p>
        <p>
          Check that it matches the fingerprint below before you import and start using the key.
        </p>
        <pre>
          <code>
            {gpgFingerprint.trim()}
          </code>
        </pre>
      </section>
    </>
  );
}
